==> eiffelstudio-18.07.10.1981.tar: F_code/C16/et760.c <==
/*
 * Code for class ET_BINARY_INTEGER_CONSTANT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "et760.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ET_BINARY_INTEGER_CONSTANT}.make */
void F1561_14405 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	F1058_10012(Current);
	F1561_14416(Current);
	RTLE;
}

/* {ET_BINARY_INTEGER_CONSTANT}.is_binary */
EIF_BOOLEAN F1561_14410 (EIF_REFERENCE Current)
{
	return (EIF_BOOLEAN) EIF_TRUE;
}

/* {ET_BINARY_INTEGER_CONSTANT}.is_integer_8 */
EIF_BOOLEAN F1561_14411 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_NATURAL_64 tu8_1;
	EIF_NATURAL_64 tu8_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_5_0_)) {
		RTLE;
		return (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		loc1 = tr1;
		if ((EIF_BOOLEAN) !EIF_TEST(loc1)) {
			tu8_1 = *(EIF_NATURAL_64 *)(Current+ _I64OFF_5_1_0_2_0_0_0_);
			tu8_2 = (EIF_NATURAL_64) ((EIF_NATURAL_8) 255U);
			Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (tu8_1 <= tu8_2);
		} else {
			tb1 = F1535_14103(loc1);
			if (tb1) {
				tu8_1 = *(EIF_NATURAL_64 *)(Current+ _I64OFF_5_1_0_2_0_0_0_);
				tu8_2 = RTOSCF(14380,F1556_14380,(Current));
				Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (tu8_1 <= tu8_2);
			} else {
				tu8_1 = *(EIF_NATURAL_64 *)(Current+ _I64OFF_5_1_0_2_0_0_0_);
				tu8_2 = (EIF_NATURAL_64) ((EIF_INTEGER_8) 127L);
				Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (tu8_1 <= tu8_2);
			}
		}
	}
	RTLE;
	return Result;
}

/* {ET_BINARY_INTEGER_CONSTANT}.is_integer_16 */
EIF_BOOLEAN F1561_14412 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_NATURAL_64 tu8_1;
	EIF_NATURAL_64 tu8_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_5_0_)) {
		RTLE;
		return (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		loc1 = tr1;
		if ((EIF_BOOLEAN) !EIF_TEST(loc1)) {
			tu8_1 = *(EIF_NATURAL_64 *)(Current+ _I64OFF_5_1_0_2_0_0_0_);
			tu8_2 = (EIF_NATURAL_64) ((EIF_NATURAL_16) 65535U);
			Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (tu8_1 <= tu8_2);
		} else {
			tb1 = F1535_14103(loc1);
			if (tb1) {
				tu8_1 = *(EIF_NATURAL_64 *)(Current+ _I64OFF_5_1_0_2_0_0_0_);
				tu8_2 = RTOSCF(14381,F1556_14381,(Current));
				Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (tu8_1 <= tu8_2);
			} else {
				tu8_1 = *(EIF_NATURAL_64 *)(Current+ _I64OFF_5_1_0_2_0_0_0_);
				tu8_2 = (EIF_NATURAL_64) ((EIF_INTEGER_16) 32767L);
				Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (tu8_1 <= tu8_2);
			}
		}
	}
	RTLE;
	return Result;
}

/* {ET_BINARY_INTEGER_CONSTANT}.is_integer_32 */
EIF_BOOLEAN F1561_14413 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_NATURAL_64 tu8_1;
	EIF_NATURAL_64 tu8_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_5_0_)) {
		RTLE;
		return (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		loc1 = tr1;
		if ((EIF_BOOLEAN) !EIF_TEST(loc1)) {
			tu8_1 = *(EIF_NATURAL_64 *)(Current+ _I64OFF_5_1_0_2_0_0_0_);
			tu8_2 = (EIF_NATURAL_64) ((EIF_NATURAL_32) 4294967295U);
			Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (tu8_1 <= tu8_2);
		} else {
			tb1 = F1535_14103(loc1);
			if (tb1) {
				tu8_1 = *(EIF_NATURAL_64 *)(Current+ _I64OFF_5_1_0_2_0_0_0_);
				tu8_2 = RTOSCF(14382,F1556_14382,(Current));
				Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (tu8_1 <= tu8_2);
			} else {
				tu8_1 = *(EIF_NATURAL_64 *)(Current+ _I64OFF_5_1_0_2_0_0_0_);
				tu8_2 = (EIF_NATURAL_64) ((EIF_INTEGER_32) 2147483647L);
				Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (tu8_1 <= tu8_2);
			}
		}
	}
	RTLE;
	return Result;
}

/* {ET_BINARY_INTEGER_CONSTANT}.is_integer_64 */
EIF_BOOLEAN F1561_14414 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_NATURAL_64 tu8_1;
	EIF_NATURAL_64 tu8_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_5_0_)) {
		RTLE;
		return (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		loc1 = tr1;
		if ((EIF_BOOLEAN) !EIF_TEST(loc1)) {
			Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		} else {
			tb1 = F1535_14103(loc1);
			if (tb1) {
				tu8_1 = *(EIF_NATURAL_64 *)(Current+ _I64OFF_5_1_0_2_0_0_0_);
				tu8_2 = RTOSCF(14383,F1556_14383,(Current));
				Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (tu8_1 <= tu8_2);
			} else {
				tu8_1 = *(EIF_NATURAL_64 *)(Current+ _I64OFF_5_1_0_2_0_0_0_);
				tu8_2 = (EIF_NATURAL_64) ((EIF_INTEGER_64) RTI64C(9223372036854775807));
				Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (tu8_1 <= tu8_2);
			}
		}
	}
	RTLE;
	return Result;
}

/* {ET_BINARY_INTEGER_CONSTANT}.process */
void F1561_14415 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R1167[Dtype(arg1)-141])(RTCW(arg1), Current);
}

/* {ET_BINARY_INTEGER_CONSTANT}.compute_value */
void F1561_14416 (EIF_REFERENCE Current)
{
	GTCX
	EIF_NATURAL_64 loc1 = (EIF_NATURAL_64) 0;
	EIF_NATURAL_64 loc2 = (EIF_NATURAL_64) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_NATURAL_64 loc5 = (EIF_NATURAL_64) 0;
	EIF_NATURAL_64 loc6 = (EIF_NATURAL_64) 0;
	EIF_NATURAL_32 loc7 = (EIF_NATURAL_32) 0;
	EIF_CHARACTER_8 loc8 = (EIF_CHARACTER_8) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_NATURAL_32 tu4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	loc7 = (EIF_NATURAL_32) (EIF_CHARACTER_8) '0';
	loc5 = (EIF_NATURAL_64) (EIF_NATURAL_64) (((EIF_NATURAL_64) RTU64C(18446744073709551615)) / (EIF_NATURAL_64) ((EIF_INTEGER_32) 2L));
	loc6 = (EIF_NATURAL_64) (EIF_NATURAL_64) (((EIF_NATURAL_64) RTU64C(18446744073709551615)) % (EIF_NATURAL_64) ((EIF_INTEGER_32) 2L));
	*(EIF_BOOLEAN *)(Current+ _CHROFF_5_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc4 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_1_0_2_);
	loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 3L);
	for (;;) {
		if ((EIF_BOOLEAN) (loc3 > loc4)) break;
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		loc8 = *(EIF_CHARACTER_8 *)(eif_optimize_return = 1, (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R4638[Dtype(tr1)-644])(RTCW(tr1), loc3));
		if ((EIF_BOOLEAN)(loc8 != (EIF_CHARACTER_8) '_')) {
			tu4_1 = (EIF_NATURAL_32) loc8;
			loc2 = (EIF_NATURAL_64) (EIF_NATURAL_32) (tu4_1 - loc7);
			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc1 < loc5) || (EIF_BOOLEAN) ((EIF_BOOLEAN)(loc1 == loc5) && (EIF_BOOLEAN) (loc2 <= loc6)))) {
				loc1 = (EIF_NATURAL_64) (EIF_NATURAL_64) ((EIF_NATURAL_64) ((EIF_NATURAL_64) ((EIF_INTEGER_32) 2L) * loc1) + loc2);
			} else {
				*(EIF_BOOLEAN *)(Current+ _CHROFF_5_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
				loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 + ((EIF_INTEGER_32) 1L));
			}
		}
		loc3++;
	}
	*(EIF_NATURAL_64 *)(Current+ _I64OFF_5_1_0_2_0_0_0_) = (EIF_NATURAL_64) loc1;
	RTLE;
}

void EIF_Minit760 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C16/et760.c <==
/*
 * Code for class ET_OCTAL_INTEGER_CONSTANT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "et760.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ET_OCTAL_INTEGER_CONSTANT}.make */
void F1562_14442 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	F1060_10052(Current);
	F1562_14444(Current);
	RTLE;
}

/* {ET_OCTAL_INTEGER_CONSTANT}.process */
void F1562_14443 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R1306[Dtype(arg1)-141])(RTCW(arg1), Current);
}

/* {ET_OCTAL_INTEGER_CONSTANT}.compute_value */
void F1562_14444 (EIF_REFERENCE Current)
{
	GTCX
	EIF_NATURAL_64 loc1 = (EIF_NATURAL_64) 0;
	EIF_NATURAL_64 loc2 = (EIF_NATURAL_64) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_NATURAL_64 loc5 = (EIF_NATURAL_64) 0;
	EIF_NATURAL_64 loc6 = (EIF_NATURAL_64) 0;
	EIF_NATURAL_32 loc7 = (EIF_NATURAL_32) 0;
	EIF_CHARACTER_8 loc8 = (EIF_CHARACTER_8) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_NATURAL_32 tu4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	loc7 = (EIF_NATURAL_32) (EIF_CHARACTER_8) '0';
	loc5 = (EIF_NATURAL_64) (EIF_NATURAL_64) (((EIF_NATURAL_64) RTU64C(18446744073709551615)) / (EIF_NATURAL_64) ((EIF_INTEGER_32) 8L));
	loc6 = (EIF_NATURAL_64) (EIF_NATURAL_64) (((EIF_NATURAL_64) RTU64C(18446744073709551615)) % (EIF_NATURAL_64) ((EIF_INTEGER_32) 8L));
	*(EIF_BOOLEAN *)(Current+ _CHROFF_5_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc4 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_1_0_2_);
	loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 3L);
	for (;;) {
		if ((EIF_BOOLEAN) (loc3 > loc4)) break;
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		loc8 = *(EIF_CHARACTER_8 *)(eif_optimize_return = 1, (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R4664[Dtype(tr1)-646])(RTCW(tr1), loc3));
		if ((EIF_BOOLEAN)(loc8 != (EIF_CHARACTER_8) '_')) {
			tu4_1 = (EIF_NATURAL_32) loc8;
			loc2 = (EIF_NATURAL_64) (EIF_NATURAL_32) (tu4_1 - loc7);
			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc1 < loc5) || (EIF_BOOLEAN) ((EIF_BOOLEAN)(loc1 == loc5) && (EIF_BOOLEAN) (loc2 <= loc6)))) {
				loc1 = (EIF_NATURAL_64) (EIF_NATURAL_64) ((EIF_NATURAL_64) ((EIF_NATURAL_64) ((EIF_INTEGER_32) 8L) * loc1) + loc2);
			} else {
				*(EIF_BOOLEAN *)(Current+ _CHROFF_5_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
				loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 + ((EIF_INTEGER_32) 1L));
			}
		}
		loc3++;
	}
	*(EIF_NATURAL_64 *)(Current+ _I64OFF_5_1_0_2_0_0_0_) = (EIF_NATURAL_64) loc1;
	RTLE;
}

void EIF_Minit760 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
